colour.colorimetry.dataset.illuminants.d_illuminants_s_spds Module — Colour 0.3.0 documentation

# colour.colorimetry.dataset.illuminants.d_illuminants_s_spds Module

## CIE Standard Illuminant D Series \(S_n(\lambda)\) Spectral Power Distributions

Defines the CIE Standard Illuminant D Series \(S_n(\lambda)\) spectral power distributions involved in the computation of CIE Standard Illuminant D Series relative spectral power distributions.

See also

Illuminants IPython Notebook

References

[1] | Wyszecki & Stiles, Color Science - Concepts and Methods Data and Formulae - Second Edition, Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3, page 146.

[2] | http://www.brucelindbloom.com/index.html?Eqn_DIlluminant.html (Last accessed 5 April 2014)

`colour.colorimetry.dataset.illuminants.d_illuminants_s_spds.` `D_ILLUMINANTS_S_SPDS` = CaseInsensitiveMapping({u'S2': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf83d0>, u'S1': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8390>, u'S0': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x102cf8350>})

  CIE Standard Illuminant D Series \(S_n(\lambda)\) spectral power distributions

  D_ILLUMINANTS_S_SPDS : dict
    (‘S0’, ‘S1’, ‘S1’)